==> opencl-clhpp-2.0.15-1-any.pkg.tar.zst: usr/share/doc/opencl-clhpp/opencl_8hpp.js <==
var opencl_8hpp =
[
    [ "cl::detail::param_traits< enum_type, Name >", "structcl_1_1detail_1_1param__traits.html", null ],
    [ "cl::detail::GetInfoFunctor0< Func, Arg0 >", "structcl_1_1detail_1_1_get_info_functor0.html", null ],
    [ "cl::detail::GetInfoFunctor1< Func, Arg0, Arg1 >", "structcl_1_1detail_1_1_get_info_functor1.html", null ],
    [ "cl::detail::ReferenceHandler< T >", "structcl_1_1detail_1_1_reference_handler.html", null ],
    [ "cl::detail::ReferenceHandler< cl_device_id >", "structcl_1_1detail_1_1_reference_handler_3_01cl__device__id_01_4.html", null ],
    [ "cl::detail::ReferenceHandler< cl_platform_id >", "structcl_1_1detail_1_1_reference_handler_3_01cl__platform__id_01_4.html", null ],
    [ "cl::detail::ReferenceHandler< cl_context >", "structcl_1_1detail_1_1_reference_handler_3_01cl__context_01_4.html", null ],
    [ "cl::detail::ReferenceHandler< cl_command_queue >", "structcl_1_1detail_1_1_reference_handler_3_01cl__command__queue_01_4.html", null ],
    [ "cl::detail::ReferenceHandler< cl_mem >", "structcl_1_1detail_1_1_reference_handler_3_01cl__mem_01_4.html", null ],
    [ "cl::detail::ReferenceHandler< cl_sampler >", "structcl_1_1detail_1_1_reference_handler_3_01cl__sampler_01_4.html", null ],
    [ "cl::detail::ReferenceHandler< cl_program >", "structcl_1_1detail_1_1_reference_handler_3_01cl__program_01_4.html", null ],
    [ "cl::detail::ReferenceHandler< cl_kernel >", "structcl_1_1detail_1_1_reference_handler_3_01cl__kernel_01_4.html", null ],
    [ "cl::detail::ReferenceHandler< cl_event >", "structcl_1_1detail_1_1_reference_handler_3_01cl__event_01_4.html", null ],
    [ "cl::detail::Wrapper< T >", "classcl_1_1detail_1_1_wrapper.html", null ],
    [ "cl::detail::Wrapper< cl_device_id >", "classcl_1_1detail_1_1_wrapper_3_01cl__device__id_01_4.html", null ],
    [ "cl::ImageFormat", "structcl_1_1_image_format.html", "structcl_1_1_image_format" ],
    [ "cl::Device", "classcl_1_1_device.html", "classcl_1_1_device" ],
    [ "cl::Platform", "classcl_1_1_platform.html", "classcl_1_1_platform" ],
    [ "cl::Context", "classcl_1_1_context.html", "classcl_1_1_context" ],
    [ "cl::Event", "classcl_1_1_event.html", "classcl_1_1_event" ],
    [ "cl::UserEvent", "classcl_1_1_user_event.html", "classcl_1_1_user_event" ],
    [ "cl::Memory", "classcl_1_1_memory.html", "classcl_1_1_memory" ],
    [ "cl::detail::SVMTraitNull", "classcl_1_1detail_1_1_s_v_m_trait_null.html", null ],
    [ "cl::SVMTraitReadWrite< Trait >", "classcl_1_1_s_v_m_trait_read_write.html", null ],
    [ "cl::SVMTraitReadOnly< Trait >", "classcl_1_1_s_v_m_trait_read_only.html", null ],
    [ "cl::SVMTraitWriteOnly< Trait >", "classcl_1_1_s_v_m_trait_write_only.html", null ],
    [ "cl::SVMTraitCoarse< Trait >", "classcl_1_1_s_v_m_trait_coarse.html", null ],
    [ "cl::SVMTraitFine< Trait >", "classcl_1_1_s_v_m_trait_fine.html", null ],
    [ "cl::SVMTraitAtomic< Trait >", "classcl_1_1_s_v_m_trait_atomic.html", null ],
    [ "cl::SVMAllocator< T, SVMTrait >", "classcl_1_1_s_v_m_allocator.html", "classcl_1_1_s_v_m_allocator" ],
    [ "cl::SVMAllocator< T, SVMTrait >::rebind< U >", "structcl_1_1_s_v_m_allocator_1_1rebind.html", null ],
    [ "cl::SVMAllocator< void, SVMTrait >", "classcl_1_1_s_v_m_allocator_3_01void_00_01_s_v_m_trait_01_4.html", "classcl_1_1_s_v_m_allocator_3_01void_00_01_s_v_m_trait_01_4" ],
    [ "cl::SVMAllocator< void, SVMTrait >::rebind< U >", "structcl_1_1_s_v_m_allocator_3_01void_00_01_s_v_m_trait_01_4_1_1rebind.html", null ],
    [ "cl::detail::Deleter< Alloc >", "classcl_1_1detail_1_1_deleter.html", null ],
    [ "cl::Buffer", "classcl_1_1_buffer.html", "classcl_1_1_buffer" ],
    [ "cl::BufferGL", "classcl_1_1_buffer_g_l.html", "classcl_1_1_buffer_g_l" ],
    [ "cl::BufferRenderGL", "classcl_1_1_buffer_render_g_l.html", "classcl_1_1_buffer_render_g_l" ],
    [ "cl::Image", "classcl_1_1_image.html", "classcl_1_1_image" ],
    [ "cl::Image1D", "classcl_1_1_image1_d.html", "classcl_1_1_image1_d" ],
    [ "cl::Image1DBuffer", "classcl_1_1_image1_d_buffer.html", "classcl_1_1_image1_d_buffer" ],
    [ "cl::Image1DArray", "classcl_1_1_image1_d_array.html", "classcl_1_1_image1_d_array" ],
    [ "cl::Image2D", "classcl_1_1_image2_d.html", "classcl_1_1_image2_d" ],
    [ "cl::Image2DGL", "classcl_1_1_image2_d_g_l.html", "classcl_1_1_image2_d_g_l" ],
    [ "cl::Image2DArray", "classcl_1_1_image2_d_array.html", "classcl_1_1_image2_d_array" ],
    [ "cl::Image3D", "classcl_1_1_image3_d.html", "classcl_1_1_image3_d" ],
    [ "cl::Image3DGL", "classcl_1_1_image3_d_g_l.html", "classcl_1_1_image3_d_g_l" ],
    [ "cl::ImageGL", "classcl_1_1_image_g_l.html", "classcl_1_1_image_g_l" ],
    [ "cl::Pipe", "classcl_1_1_pipe.html", "classcl_1_1_pipe" ],
    [ "cl::Sampler", "classcl_1_1_sampler.html", "classcl_1_1_sampler" ],
    [ "cl::NDRange", "classcl_1_1_n_d_range.html", "classcl_1_1_n_d_range" ],
    [ "cl::LocalSpaceArg", "structcl_1_1_local_space_arg.html", null ],
    [ "cl::detail::KernelArgumentHandler< T, typename std::enable_if<!std::is_base_of< cl::Memory, T >::value >::type >", "structcl_1_1detail_1_1_kernel_argument_handler_3_01_t_00_01typename_01std_1_1enable__if_3_9std_10affa824618af864313998f2e6bcf08f.html", null ],
    [ "cl::detail::KernelArgumentHandler< T, typename std::enable_if< std::is_base_of< cl::Memory, T >::value >::type >", "structcl_1_1detail_1_1_kernel_argument_handler_3_01_t_00_01typename_01std_1_1enable__if_3_01std_cb5bfaca8096193f715a7bbe8a3fa84f.html", null ],
    [ "cl::detail::KernelArgumentHandler< LocalSpaceArg, void >", "structcl_1_1detail_1_1_kernel_argument_handler_3_01_local_space_arg_00_01void_01_4.html", null ],
    [ "cl::Kernel", "classcl_1_1_kernel.html", "classcl_1_1_kernel" ],
    [ "cl::Program", "classcl_1_1_program.html", "classcl_1_1_program" ],
    [ "cl::CommandQueue", "classcl_1_1_command_queue.html", "classcl_1_1_command_queue" ],
    [ "cl::DeviceCommandQueue", "classcl_1_1_device_command_queue.html", "classcl_1_1_device_command_queue" ],
    [ "cl::detail::KernelArgumentHandler< cl::DeviceCommandQueue, void >", "structcl_1_1detail_1_1_kernel_argument_handler_3_01cl_1_1_device_command_queue_00_01void_01_4.html", null ],
    [ "cl::EnqueueArgs", "classcl_1_1_enqueue_args.html", null ],
    [ "cl::KernelFunctor< Ts >", "classcl_1_1_kernel_functor.html", "classcl_1_1_kernel_functor" ],
    [ "cl::compatibility::make_kernel< Ts >", "structcl_1_1compatibility_1_1make__kernel.html", "structcl_1_1compatibility_1_1make__kernel" ],
    [ "atomic_svm_vector", "opencl_8hpp.html#aebc48a598e41f0cb98397460ca04ffb6", null ],
    [ "coarse_svm_vector", "opencl_8hpp.html#abd957be3ad58ee2932a99ed8bc6cc049", null ],
    [ "fine_svm_vector", "opencl_8hpp.html#a048aa194c540d1a3178054256db082b9", null ],
    [ "allocate_pointer", "opencl_8hpp.html#a8e1fce10cd1b8118f51aa91ce0a589e5", null ],
    [ "copy", "opencl_8hpp.html#a05791e9d5da23b21abd6e319fb262c9f", null ],
    [ "copy", "opencl_8hpp.html#a02c4368c6ce7a1a99132eafd5dc96fa9", null ],
    [ "copy", "opencl_8hpp.html#a2f71ed9a316daf59c03c0f3ba62f1bd3", null ],
    [ "copy", "opencl_8hpp.html#a1197a833cdd6664f206b079f2bebd2eb", null ],
    [ "enqueueMapSVM", "opencl_8hpp.html#a7aa80934f265ff5c97b715419aa38566", null ],
    [ "enqueueMapSVM", "opencl_8hpp.html#a8037dc6274012b061edabe1550a2c0ee", null ],
    [ "enqueueMapSVM", "opencl_8hpp.html#abb2c4e45814ea569a27c39d37471b2a4", null ],
    [ "enqueueUnmapSVM", "opencl_8hpp.html#aa1c4d75a33c1d658ca4abae23376f733", null ],
    [ "enqueueUnmapSVM", "opencl_8hpp.html#a5c0670097b79b7f6fd2762bae83328f4", null ],
    [ "enqueueUnmapSVM", "opencl_8hpp.html#a45d896e5d437b505648b399dbe1c3cac", null ],
    [ "Local", "opencl_8hpp.html#a2f9d06d8196d7a2f4cf196d5bb7e5dd0", null ],
    [ "mapSVM", "opencl_8hpp.html#ae97dc5bb86e2c3c3935280a86cda301c", null ],
    [ "UnloadCompiler", "opencl_8hpp.html#a2fc824c118740089633cc15e7107f3f0", null ],
    [ "unmapSVM", "opencl_8hpp.html#af9f49b386b20c55c04a9e6cd21849fd5", null ]
];

==> opencl-clhpp-2024.10.24-1-any.pkg.tar.zst: usr/share/doc/opencl-clhpp/opencl_8hpp.js <==
var opencl_8hpp =
[
    [ "cl::detail::param_traits< enum_type, Name >", "structcl_1_1detail_1_1param__traits.html", null ],
    [ "cl::detail::GetInfoFunctor0< Func, Arg0 >", "structcl_1_1detail_1_1_get_info_functor0.html", null ],
    [ "cl::detail::GetInfoFunctor1< Func, Arg0, Arg1 >", "structcl_1_1detail_1_1_get_info_functor1.html", null ],
    [ "cl::detail::ReferenceHandler< T >", "structcl_1_1detail_1_1_reference_handler.html", null ],
    [ "cl::detail::ReferenceHandler< cl_device_id >", "structcl_1_1detail_1_1_reference_handler_3_01cl__device__id_01_4.html", null ],
    [ "cl::detail::ReferenceHandler< cl_platform_id >", "structcl_1_1detail_1_1_reference_handler_3_01cl__platform__id_01_4.html", null ],
    [ "cl::detail::ReferenceHandler< cl_context >", "structcl_1_1detail_1_1_reference_handler_3_01cl__context_01_4.html", null ],
    [ "cl::detail::ReferenceHandler< cl_command_queue >", "structcl_1_1detail_1_1_reference_handler_3_01cl__command__queue_01_4.html", null ],
    [ "cl::detail::ReferenceHandler< cl_mem >", "structcl_1_1detail_1_1_reference_handler_3_01cl__mem_01_4.html", null ],
    [ "cl::detail::ReferenceHandler< cl_sampler >", "structcl_1_1detail_1_1_reference_handler_3_01cl__sampler_01_4.html", null ],
    [ "cl::detail::ReferenceHandler< cl_program >", "structcl_1_1detail_1_1_reference_handler_3_01cl__program_01_4.html", null ],
    [ "cl::detail::ReferenceHandler< cl_kernel >", "structcl_1_1detail_1_1_reference_handler_3_01cl__kernel_01_4.html", null ],
    [ "cl::detail::ReferenceHandler< cl_event >", "structcl_1_1detail_1_1_reference_handler_3_01cl__event_01_4.html", null ],
    [ "cl::detail::Wrapper< T >", "classcl_1_1detail_1_1_wrapper.html", null ],
    [ "cl::detail::Wrapper< cl_device_id >", "classcl_1_1detail_1_1_wrapper_3_01cl__device__id_01_4.html", null ],
    [ "cl::ImageFormat", "structcl_1_1_image_format.html", "structcl_1_1_image_format" ],
    [ "cl::Device", "classcl_1_1_device.html", "classcl_1_1_device" ],
    [ "cl::Platform", "classcl_1_1_platform.html", "classcl_1_1_platform" ],
    [ "cl::Context", "classcl_1_1_context.html", "classcl_1_1_context" ],
    [ "cl::Event", "classcl_1_1_event.html", "classcl_1_1_event" ],
    [ "cl::UserEvent", "classcl_1_1_user_event.html", "classcl_1_1_user_event" ],
    [ "cl::Memory", "classcl_1_1_memory.html", "classcl_1_1_memory" ],
    [ "cl::detail::SVMTraitNull", "classcl_1_1detail_1_1_s_v_m_trait_null.html", null ],
    [ "cl::SVMTraitReadWrite< Trait >", "classcl_1_1_s_v_m_trait_read_write.html", null ],
    [ "cl::SVMTraitReadOnly< Trait >", "classcl_1_1_s_v_m_trait_read_only.html", null ],
    [ "cl::SVMTraitWriteOnly< Trait >", "classcl_1_1_s_v_m_trait_write_only.html", null ],
    [ "cl::SVMTraitCoarse< Trait >", "classcl_1_1_s_v_m_trait_coarse.html", null ],
    [ "cl::SVMTraitFine< Trait >", "classcl_1_1_s_v_m_trait_fine.html", null ],
    [ "cl::SVMTraitAtomic< Trait >", "classcl_1_1_s_v_m_trait_atomic.html", null ],
    [ "cl::SVMAllocator< T, SVMTrait >", "classcl_1_1_s_v_m_allocator.html", "classcl_1_1_s_v_m_allocator" ],
    [ "cl::SVMAllocator< T, SVMTrait >::rebind< U >", "structcl_1_1_s_v_m_allocator_1_1rebind.html", null ],
    [ "cl::SVMAllocator< void, SVMTrait >", "classcl_1_1_s_v_m_allocator_3_01void_00_01_s_v_m_trait_01_4.html", "classcl_1_1_s_v_m_allocator_3_01void_00_01_s_v_m_trait_01_4" ],
    [ "cl::SVMAllocator< void, SVMTrait >::rebind< U >", "structcl_1_1_s_v_m_allocator_3_01void_00_01_s_v_m_trait_01_4_1_1rebind.html", "structcl_1_1_s_v_m_allocator_3_01void_00_01_s_v_m_trait_01_4_1_1rebind" ],
    [ "cl::detail::Deleter< Alloc >", "classcl_1_1detail_1_1_deleter.html", null ],
    [ "cl::Buffer", "classcl_1_1_buffer.html", "classcl_1_1_buffer" ],
    [ "cl::BufferGL", "classcl_1_1_buffer_g_l.html", "classcl_1_1_buffer_g_l" ],
    [ "cl::BufferRenderGL", "classcl_1_1_buffer_render_g_l.html", "classcl_1_1_buffer_render_g_l" ],
    [ "cl::Image", "classcl_1_1_image.html", "classcl_1_1_image" ],
    [ "cl::Image1D", "classcl_1_1_image1_d.html", "classcl_1_1_image1_d" ],
    [ "cl::Image1DBuffer", "classcl_1_1_image1_d_buffer.html", "classcl_1_1_image1_d_buffer" ],
    [ "cl::Image1DArray", "classcl_1_1_image1_d_array.html", "classcl_1_1_image1_d_array" ],
    [ "cl::Image2D", "classcl_1_1_image2_d.html", "classcl_1_1_image2_d" ],
    [ "cl::Image2DGL", "classcl_1_1_image2_d_g_l.html", "classcl_1_1_image2_d_g_l" ],
    [ "cl::Image2DArray", "classcl_1_1_image2_d_array.html", "classcl_1_1_image2_d_array" ],
    [ "cl::Image3D", "classcl_1_1_image3_d.html", "classcl_1_1_image3_d" ],
    [ "cl::Image3DGL", "classcl_1_1_image3_d_g_l.html", "classcl_1_1_image3_d_g_l" ],
    [ "cl::ImageGL", "classcl_1_1_image_g_l.html", "classcl_1_1_image_g_l" ],
    [ "cl::Pipe", "classcl_1_1_pipe.html", "classcl_1_1_pipe" ],
    [ "cl::Sampler", "classcl_1_1_sampler.html", "classcl_1_1_sampler" ],
    [ "cl::NDRange", "classcl_1_1_n_d_range.html", "classcl_1_1_n_d_range" ],
    [ "cl::LocalSpaceArg", "structcl_1_1_local_space_arg.html", null ],
    [ "cl::detail::KernelArgumentHandler< T, typename std::enable_if<!std::is_base_of< cl::Memory, T >::value >::type >", "structcl_1_1detail_1_1_kernel_argument_handler_3_01_t_00_01typename_01std_1_1enable__if_3_9std_10affa824618af864313998f2e6bcf08f.html", null ],
    [ "cl::detail::KernelArgumentHandler< T, typename std::enable_if< std::is_base_of< cl::Memory, T >::value >::type >", "structcl_1_1detail_1_1_kernel_argument_handler_3_01_t_00_01typename_01std_1_1enable__if_3_01std_cb5bfaca8096193f715a7bbe8a3fa84f.html", null ],
    [ "cl::detail::KernelArgumentHandler< LocalSpaceArg, void >", "structcl_1_1detail_1_1_kernel_argument_handler_3_01_local_space_arg_00_01void_01_4.html", null ],
    [ "cl::Kernel", "classcl_1_1_kernel.html", "classcl_1_1_kernel" ],
    [ "cl::Program", "classcl_1_1_program.html", "classcl_1_1_program" ],
    [ "cl::CommandQueue", "classcl_1_1_command_queue.html", "classcl_1_1_command_queue" ],
    [ "cl::DeviceCommandQueue", "classcl_1_1_device_command_queue.html", "classcl_1_1_device_command_queue" ],
    [ "cl::detail::KernelArgumentHandler< cl::DeviceCommandQueue, void >", "structcl_1_1detail_1_1_kernel_argument_handler_3_01cl_1_1_device_command_queue_00_01void_01_4.html", null ],
    [ "cl::EnqueueArgs", "classcl_1_1_enqueue_args.html", null ],
    [ "cl::KernelFunctor< Ts >", "classcl_1_1_kernel_functor.html", "classcl_1_1_kernel_functor" ],
    [ "cl::compatibility::make_kernel< Ts >", "structcl_1_1compatibility_1_1make__kernel.html", "structcl_1_1compatibility_1_1make__kernel" ],
    [ "cl::atomic_svm_vector", "namespacecl.html#a445d7d2f4c3234dc5fbd2d254eb39e22", null ],
    [ "cl::coarse_svm_vector", "namespacecl.html#a2903d8ce897eef7efca4ab6f32f2a197", null ],
    [ "cl::fine_svm_vector", "namespacecl.html#a43fd451f30944f957126b167b4eb0664", null ],
    [ "cl::allocate_pointer", "namespacecl.html#a8e1fce10cd1b8118f51aa91ce0a589e5", null ],
    [ "cl::copy", "namespacecl.html#a05791e9d5da23b21abd6e319fb262c9f", null ],
    [ "cl::copy", "namespacecl.html#a02c4368c6ce7a1a99132eafd5dc96fa9", null ],
    [ "cl::copy", "namespacecl.html#a2f71ed9a316daf59c03c0f3ba62f1bd3", null ],
    [ "cl::copy", "namespacecl.html#a1197a833cdd6664f206b079f2bebd2eb", null ],
    [ "cl::enqueueMapSVM", "namespacecl.html#a640c02cb285c5ab57ab8669bc2146643", null ],
    [ "cl::enqueueMapSVM", "namespacecl.html#a85686c89497c3ef296e3cf1840d7d725", null ],
    [ "cl::enqueueMapSVM", "namespacecl.html#ae48b9857ac37b027d8e946f0cf3c3232", null ],
    [ "cl::enqueueUnmapSVM", "namespacecl.html#a9835d1b49011a71e71b602c8b4db261e", null ],
    [ "cl::enqueueUnmapSVM", "namespacecl.html#ab2784dad151e0aed0685067d190dc994", null ],
    [ "cl::enqueueUnmapSVM", "namespacecl.html#ab76105928c721c5a922a4c1aea804e87", null ],
    [ "cl::Local", "namespacecl.html#a2f9d06d8196d7a2f4cf196d5bb7e5dd0", null ],
    [ "cl::mapSVM", "namespacecl.html#ae97dc5bb86e2c3c3935280a86cda301c", null ],
    [ "cl::UnloadCompiler", "namespacecl.html#a2fc824c118740089633cc15e7107f3f0", null ],
    [ "cl::unmapSVM", "namespacecl.html#af9f49b386b20c55c04a9e6cd21849fd5", null ]
];
